==> Mojo-Weixin-1.2.7.tar.gz: Mojo-Weixin-1.2.7/Plugin.md <==
###插件列表

|名称                | 优先级  |当前状态    |github作者   | 功能说明                 
|:-------------------|:--------|:-----------|:------------|:----------------------------
|[ShowMsg]           |100      |已发布      |sjdy521      |打印客户端接收和发送的消息
|[ImageStore]        |100      |已发布      |sjdy521      |按日期目录保存发送和接收的图片
|[IRCShell]          |99       |已发布      |sjdy521      |Linux环境下通过irc客户端使用微信
|[Openwx]            |98       |已发布      |sjdy521      |提供微信发送消息api接口
|[Perlcode]          |97       |已发布      |sjdy521      |通过微信消息执行perl代码
|[Perldoc]           |96       |已发布      |sjdy521      |通过微信消息查询perl文档
|[Beauty]            |95       |已发布      |sjdy521      |识别指定关键字发送美女图片
|[Translation]       |93       |已发布      |sjdy521      |多国语言翻译功能
|[Riddle]            |92       |已发布      |limengyu1990 |输入"猜谜"关键字进行猜谜游戏
|[Weather]           |91       |不可用      |autodataming |输入"北京天气"查询指定地区天气
|[KnowledgeBase]     |2        |已发布      |sjdy521      | 通过微信消息自定义问答知识库
|[FuckDaShen]        |1        |已发布      |sjdy521      |对消息中的"大神"关键词进行鄙视
|[AutoVerify]        |1        |已发布      |sjdy521      |收到好友验证请求时自动批准同意
|[PostQRcode]        |0        |已发布      |sjdy521      |登录二维码发送到邮箱实现远程扫码
|[UploadQRcode]      |0        |已发布      |sjdy521      |二维码上传图床获得公网访问url
|[XiaoiceReply]      |1        |已发布      |sjdy521      |利用微软小冰实现智能聊天回复
|[ShowQRcode]        |0        |已发布      |sjdy521      |调用系统图片查看程序来示二维码（目前仅支持win）
|[ShowQRCodeInTerm]  |0        |已发布      |hyvinlam     |Linux系统下直接打印二维码到终端
|[SmartReply]        |0        |已发布      |sjdy521      |智能聊天回复

[ShowMsg]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::ShowMsg
[ImageStore]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::ImageStore
[IRCShell]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::IRCShell
[Openwx]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Openwx
[Perlcode]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Perlcode)
[Perldoc]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Perldoc
[Beauty]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Beauty
[Translation]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Translation
[Riddle]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Riddle
[Weather]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Weather
[KnowledgeBase]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::KnowledgeBase 
[FuckDaShen]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::FuckDaShen
[AutoVerify]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::AutoVerify
[PostQRcode]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::PostQRcode
[UploadQRcode]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::UploadQRcode
[XiaoiceReply]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::XiaoiceReply
[ShowQRcode]: https://metacpan.org/pod/distribution/Mojo-Weixin/doc/Weixin.pod#Mojo::Weixin::Plugin::ShowQRcode
[ShowQRCodeInTerm]: https://metacpan.org/pod/distribution/Mojo-Weixin/doc/Weixin.pod#Mojo::Weixin::Plugin::ShowQRCodeInTerm
[SmartReply]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::SmartReply

==> Mojo-Weixin-1.2.9.tar.gz: Mojo-Weixin-1.2.9/Plugin.md <==
###插件列表

|名称                | 优先级  |当前状态    |github作者   | 功能说明                 
|:-------------------|:--------|:-----------|:------------|:----------------------------
|[ShowMsg]           |100      |已发布      |sjdy521      |打印客户端接收和发送的消息
|[ImageStore]        |100      |已发布      |sjdy521      |按日期目录保存发送和接收的图片
|[IRCShell]          |99       |已发布      |sjdy521      |Linux环境下通过irc客户端使用微信
|[Openwx]            |98       |已发布      |sjdy521      |提供微信发送消息api接口
|[Perlcode]          |97       |已发布      |sjdy521      |通过微信消息执行perl代码
|[GCM]               |97       |已发布      |sjdy521      |接收消息通过GCM推送到android手机
|[Perldoc]           |96       |已发布      |sjdy521      |通过微信消息查询perl文档
|[Beauty]            |95       |已发布      |sjdy521      |识别指定关键字发送美女图片
|[Translation]       |93       |已发布      |sjdy521      |多国语言翻译功能
|[Riddle]            |92       |已发布      |limengyu1990 |输入"猜谜"关键字进行猜谜游戏
|[Weather]           |91       |不可用      |autodataming |输入"北京天气"查询指定地区天气
|[KnowledgeBase]     |2        |已发布      |sjdy521      | 通过微信消息自定义问答知识库
|[FuckDaShen]        |1        |已发布      |sjdy521      |对消息中的"大神"关键词进行鄙视
|[AutoVerify]        |1        |已发布      |sjdy521      |收到好友验证请求时自动批准同意
|[PostQRcode]        |0        |已发布      |sjdy521      |登录二维码发送到邮箱实现远程扫码
|[UploadQRcode]      |0        |已发布      |sjdy521      |二维码上传图床获得公网访问url
|[XiaoiceReply]      |1        |已发布      |sjdy521      |利用微软小冰实现智能聊天回复
|[ShowQRcode]        |0        |已发布      |sjdy521      |调用系统图片查看程序来示二维码（目前仅支持win）
|[ShowQRCodeInTerm]  |0        |已发布      |hyvinlam     |Linux系统下直接打印二维码到终端
|[SmartReply]        |0        |已发布      |sjdy521      |智能聊天回复

[ShowMsg]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::ShowMsg
[ImageStore]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::ImageStore
[IRCShell]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::IRCShell
[Openwx]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Openwx
[Perlcode]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Perlcode)
[Perldoc]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Perldoc
[Beauty]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Beauty
[Translation]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Translation
[Riddle]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Riddle
[Weather]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::Weather
[KnowledgeBase]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::KnowledgeBase 
[FuckDaShen]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::FuckDaShen
[AutoVerify]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::AutoVerify
[PostQRcode]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::PostQRcode
[UploadQRcode]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::UploadQRcode
[XiaoiceReply]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::XiaoiceReply
[ShowQRcode]: https://metacpan.org/pod/distribution/Mojo-Weixin/doc/Weixin.pod#Mojo::Weixin::Plugin::ShowQRcode
[ShowQRCodeInTerm]: https://metacpan.org/pod/distribution/Mojo-Weixin/doc/Weixin.pod#Mojo::Weixin::Plugin::ShowQRCodeInTerm
[SmartReply]: https://metacpan.org/pod/distribution/Mojo-Weixin/lib/Mojo/Weixin.pod#Mojo::Weixin::Plugin::SmartReply
[GCM]: http://www.coolapk.com/apk/com.swjtu.gcmformojo
